/// <reference types="react" />
/// <reference types="google.maps" />
import React$1, { ReactChild, DetailedHTMLProps, ButtonHTMLAttributes, CSSProperties, FunctionComponent, InputHTMLAttributes, ChangeEventHandler, ReactNode, ComponentType, PropsWithChildren, ReactElement } from 'react';
import flatpickr from 'flatpickr';
import DatePicker, { DateTimePickerProps } from 'react-flatpickr';
import * as react_table from 'react-table';
import { FilterProps, Column, ColumnInterface, Row } from 'react-table';

declare const AlertVariants: {
    readonly SUCCESS: "success";
    readonly DANGER: "danger";
    readonly INFO: "info";
    readonly WARNING: "warning";
    readonly DEFAULT: "default";
};

interface AlertProps {
    label?: ReactChild;
    variant: typeof AlertVariants[keyof typeof AlertVariants];
    timer: number;
    onChange?: (...args: any) => any;
    className?: string;
    zIndex?: number;
    children?: ReactChild;
}

declare function Alert({ label, variant, timer, onChange, className, zIndex, children, }: AlertProps): JSX.Element;
declare namespace Alert {
    var displayName: string;
}

interface BackButtonProps {
    onClick?: () => void;
    text: string;
}
declare function BackButton({ text, onClick }: BackButtonProps): JSX.Element;
declare namespace BackButton {
    var displayName: string;
}

interface IBagTransactionSummary {
    copies: {
        currentBalanceTitle: string;
        deductTitle: string;
        balanceTitle: string;
    };
    currentBalance: number | string;
    deduct: number | string;
    balance: number | string;
    region?: string;
    currency?: string;
}
declare function BagTransactionSummary({ copies: { currentBalanceTitle, deductTitle, balanceTitle }, currentBalance, deduct, balance, region, currency, }: IBagTransactionSummary): JSX.Element;
declare namespace BagTransactionSummary {
    var displayName: string;
}

interface BreadcrumbProps<T extends React$1.ComponentType<any>> {
    mainText: string;
    Element: T;
    links: Array<React$1.ComponentProps<T>>;
}
/**
 * Pass a component to Element, for example, a gastby Link or React-router Link, or nextjs Link
 */
declare function Breadcrumb<T extends React$1.ComponentType<any>>({ mainText, Element, links, }: BreadcrumbProps<T>): JSX.Element;
declare namespace Breadcrumb {
    var displayName: string;
}

declare const buttonStyles: {
    approve: string;
    reject: string;
    default: string;
    warning: string;
};
interface ButtonProps extends DetailedHTMLProps<ButtonHTMLAttributes<HTMLButtonElement>, HTMLButtonElement> {
    variant?: keyof typeof buttonStyles;
    children: React$1.ReactNode;
    type?: 'button' | 'reset' | 'submit';
}
declare function Button({ variant, children, type, className, ...props }: ButtonProps): JSX.Element;
declare namespace Button {
    var displayName: string;
}

interface IButtonAdd {
    Icon: SVGType;
    onClick: () => void;
    title: string;
}

declare function ButtonAdd({ Icon, onClick, title }: IButtonAdd): JSX.Element;
declare namespace ButtonAdd {
    var displayName: string;
}

interface CardProps {
    text: string;
}
declare function Card({ text }: CardProps): JSX.Element;
declare namespace Card {
    var displayName: string;
}

interface CardStatisticsProps {
    text: string;
    count: number | string;
    Img?: SVGType;
}

declare function CardStatistics({ text, count, Img, }: CardStatisticsProps): JSX.Element;
declare namespace CardStatistics {
    var displayName: string;
}

interface CommentProps {
    avatar: string;
    name: string;
    position?: string;
    text: string;
    datetime?: string;
}
declare const Comment: React$1.NamedExoticComponent<CommentProps>;

interface CounterProps {
    variant?: 'v' | 'h' | 'qh';
    onChange: (val: number) => void;
    minVal?: number;
    maxVal?: number;
    initialVal: number;
}
/**
 * This item exposes two variants: A vertical one ('v' default) and an horizontal one ('h').
 */
declare function Counter({ variant, onChange, minVal, maxVal, initialVal, }: CounterProps): JSX.Element;
declare namespace Counter {
    var displayName: string;
}

declare const creditCardIcon: {
    MasterCard: SVGType;
    Visa: SVGType;
    AmericanExpress: SVGType;
};

interface ICreditCard {
    icon: keyof typeof creditCardIcon;
    name: string;
    number: string;
    date: string;
    selected?: boolean;
    onClick?: () => void;
}
declare function CreditCard({ icon, name, number, date, selected, onClick, }: ICreditCard): JSX.Element;
declare namespace CreditCard {
    var displayName: string;
}

interface IDarkModeSwitcher {
    className?: string;
    onChange?: (bool: boolean) => void;
    style?: CSSProperties;
    storageKey?: string;
}
/**
 * Size changes depending on font size. Use text-4xl for a good sized one.
 */
declare const DarkModeSwitcher: FunctionComponent<IDarkModeSwitcher>;

interface IDetails {
    onChange?: (selected: boolean) => void;
    children: React$1.ReactNode;
    className?: string;
    title: string;
    isOpen?: boolean;
    hideTitle?: boolean;
}
declare const Details: ({ onChange, className, children, title, isOpen, hideTitle, }: IDetails) => JSX.Element;

declare const _default: {
    date: SVGType;
    time: SVGType;
    datetime: SVGType;
};

interface FlatPickerProps {
    title?: string;
    placeholder?: string;
    onChangeHandler: flatpickr.Options.Hook;
    dateFormat?: string;
    value?: string | Date | number;
    minDate?: true | Date;
    enableTime?: boolean;
    minTime?: string;
    maxTime?: string;
    icon?: keyof typeof _default;
    className?: string;
    innerClassName?: string;
    titleClassName?: string;
    id?: string;
}
declare function FlatPicker({ title, onChangeHandler, value, minDate, enableTime, placeholder, dateFormat, minTime, maxTime, className, innerClassName, titleClassName, icon, id, }: FlatPickerProps): JSX.Element;
declare namespace FlatPicker {
    var displayName: string;
}
interface ITimePicker extends DateTimePickerProps {
    label?: string;
    icon?: keyof typeof _default;
    innerClassName?: string;
    titleClassName?: string;
}
declare const TimePicker: React$1.ForwardRefExoticComponent<ITimePicker & React$1.RefAttributes<DatePicker>>;

interface GridInfoProps {
    title?: string;
    body: Array<{
        title: string;
        text: string;
    }>;
    className?: string;
    minWidth?: string;
}
declare function GridInfo({ title, body, className, minWidth, }: GridInfoProps): JSX.Element;
declare namespace GridInfo {
    var displayName: string;
}

declare enum IconInfoVariants {
    SMALL = "small",
    MEDIUM = "medium",
    LARGE = "large"
}

interface IconInfoProps {
    label1: string;
    label2: string;
    icon: string | SVGType;
    variant?: IconInfoVariants;
}

declare function IconInfo({ label1, label2, variant, icon, }: IconInfoProps): JSX.Element;
declare namespace IconInfo {
    var displayName: string;
}

declare type dataType<T = any> = {
    value: T;
    text: string;
    Icon: SVGType;
};
interface IIconSelect<T = any> {
    data: dataType<T>[];
    longPlaceholder: string;
    smallPlaceholder: string;
    defaultValue: T;
    onChange: (data: dataType<T> | undefined) => void;
    windowWide?: number;
}

declare function IconSelect({ data, longPlaceholder, smallPlaceholder, onChange, defaultValue, windowWide, }: IIconSelect): JSX.Element;
declare namespace IconSelect {
    var displayName: string;
}

interface attachmentProp {
    position?: 'L' | 'R';
    description: string;
}
interface CommonProps {
    text?: string;
    name?: string;
    id?: string;
    disabled?: boolean;
    handleChange?: (value: string, isValid: boolean) => void;
    attachment?: attachmentProp;
    validator?: {
        test: (value: string) => boolean;
    };
}
interface NumberProps {
    type: 'number';
    value?: number;
    min?: number;
    max?: number;
    placeholder?: string;
}
interface TextProps {
    type: 'text';
    value?: string;
}
declare type InputProps = CommonProps & (NumberProps | TextProps);

declare function Input(props: InputProps): JSX.Element;
declare namespace Input {
    var displayName: string;
}

declare const lineIcons: {
    global: SVGType;
    distribution: SVGType;
    lastMille: SVGType;
    cargo: SVGType;
};

interface LineProps {
    text: string;
    line: keyof typeof lineIcons | SVGType;
    onClick?: () => void;
}
declare function Line({ text, line, onClick }: LineProps): JSX.Element;
declare namespace Line {
    var displayName: string;
}

interface LineCardProps {
    icon: keyof typeof lineIcons | SVGType;
    title: string;
    description: string;
    onClick: () => void;
}
declare function LineCard({ icon, title, description, onClick, }: LineCardProps): JSX.Element;
declare namespace LineCard {
    var displayName: string;
}

interface LinkServicesProps {
    text: string;
    number: string;
    url: string;
    copies?: {
        copy: string;
        copied: string;
    };
}
declare function LinkServices({ text, url, number, copies, }: LinkServicesProps): JSX.Element;
declare namespace LinkServices {
    var displayName: string;
}

interface LoadFileProps extends Omit<DetailedHTMLProps<InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, 'ref'> {
    srcFile?: string;
    title: string;
    titleClassName?: string;
    onChange?: ChangeEventHandler<HTMLInputElement>;
    onOpen?: (src: string) => void;
    disabled?: boolean;
    uploadIcon?: string;
    viewIcon?: string;
}

declare const LoadFile: React$1.ForwardRefExoticComponent<LoadFileProps & React$1.RefAttributes<HTMLInputElement>>;

interface ILoginCopies {
    platform: string;
    title: string;
    description: string;
    labelEmail: string;
    placeholderEmail: string;
    labelPass: string;
    placeholderPass: string;
    titleButton: string;
    labelRemind: string;
    Child?: SVGType;
}
interface IFields {
    user: string;
    password: string;
    remember?: string;
}
interface LoginProps {
    request: {
        [key: string]: string;
    };
    copies?: ILoginCopies;
    setResponse: (response: Record<string, any>, remember?: boolean) => void;
    setError?: (error: any | false) => void;
    breakpoints?: {
        L: number;
        M: number;
    };
    fields?: IFields;
    key_recaptcha: string;
    children?: React$1.ReactNode;
}

declare function Login({ request, setResponse, setError, copies, breakpoints, fields, key_recaptcha, children, }: LoginProps): JSX.Element;
declare namespace Login {
    var displayName: string;
}

interface LookImageProps {
    title: string;
    srcImg: string;
    handleDelete?: () => void;
}

declare function LookImage({ title, srcImg, handleDelete }: LookImageProps): JSX.Element;
declare namespace LookImage {
    var displayName: string;
}

declare const themeList: {
    silver: ({
        elementType: string;
        stylers: {
            color: string;
        }[];
        featureType?: undefined;
    } | {
        elementType: string;
        stylers: {
            visibility: string;
        }[];
        featureType?: undefined;
    } | {
        featureType: string;
        elementType: string;
        stylers: {
            color: string;
        }[];
    })[];
    dark: ({
        elementType: string;
        stylers: {
            color: string;
        }[];
        featureType?: undefined;
    } | {
        elementType: string;
        stylers: {
            visibility: string;
        }[];
        featureType?: undefined;
    } | {
        featureType: string;
        elementType: string;
        stylers: {
            color: string;
        }[];
    } | {
        featureType: string;
        stylers: {
            visibility: string;
        }[];
        elementType?: undefined;
    })[];
    default: never[];
};

interface ILatLng {
    lat: number;
    lng: number;
}
interface IPlace {
    location: ILatLng;
    address: string;
    address_components: google.maps.GeocoderAddressComponent[];
}
interface ThemableMap {
    theme?: keyof typeof themeList;
    className?: string;
}
interface SelectPointMapProps extends ThemableMap {
    initialCenter?: {
        center: {
            lat: number;
            lng: number;
        };
        zoom: number;
    };
    onCenterChange?: (center: IPlace) => void | Promise<void>;
    onMoved?: (center: ILatLng | undefined) => void;
    onButtonClick?: (center: IPlace) => void;
    copies?: {
        searchPlaceholder?: string;
        unknownAddress?: string;
        address?: string;
        lat?: string;
        lng?: string;
        verify?: ReactNode;
    };
    disableCenter?: boolean;
    verifyPositionClassName?: string;
    infoPanel?: boolean;
}
interface ShowRouteMapProps extends ThemableMap {
    points: Array<ILatLng>;
    timeAndDistanceCallback?: (timeAndDistance: {
        distance: number;
        time: number;
    }) => void;
    copies: {
        distance: string;
        time: string;
    };
}
declare type MapProps = {
    apiKey: string;
    language?: 'es-419' | 'en';
    region?: 'CO' | 'CL' | 'MX' | 'US';
} & (({
    type: 'selectPoint';
} & SelectPointMapProps) | ({
    type: 'showRoute';
} & ShowRouteMapProps));

declare const Map: React$1.ForwardRefExoticComponent<MapProps & React$1.RefAttributes<google.maps.Map | undefined>>;

declare type MenuComponentType = ComponentType<PropsWithChildren<any> & {
    title?: string;
    className?: string;
}> | undefined;
interface IOptionProps<T extends MenuComponentType> {
    Icon: SVGType;
    text: string;
    active?: boolean;
    Interactable?: T extends ComponentType<infer P> ? ComponentType<P> : undefined;
    props: T extends ComponentType<infer P> ? Omit<P, 'children'> : JSX.IntrinsicElements['button'];
}
interface INestedOption<T extends MenuComponentType> {
    title: string;
    options: IOptionProps<T>[];
}
interface IPersonProps<T extends MenuComponentType> {
    name: string;
    detail: string;
    image: string;
    personOptions: IOptionProps<T>[];
    fallback?: string;
}
interface IMenuProps<T extends MenuComponentType> {
    Logo: SVGType;
    title: ReactNode;
    person: Omit<IPersonProps<T>, 'personOptions'>;
    options: Array<IOptionProps<T> | INestedOption<T>>;
    personOptions: IOptionProps<T>[];
    children?: React$1.ReactNode;
    className?: string;
    fallback?: string;
}

declare function Menu<T extends MenuComponentType>({ Logo, title, person, options, personOptions, children, className, fallback, }: IMenuProps<T>): JSX.Element;
declare namespace Menu {
    var displayName: string;
}

interface ModalProps {
    children: React.ReactNode;
    isOpen?: boolean | unknown;
    titles?: {
        titleSuccess?: string;
        titleReject?: string;
    };
    events?: {
        onSuccess?: () => void;
        onReject?: () => void;
        onClose?: () => void;
    };
    buttonsOverContent?: boolean;
    className?: string;
    parent?: Element | null;
    modalKey?: string;
}

/** Use w-max or w-screen on your content. Overflow behavior must be handled by children. */
declare function Modal({ children, titles, isOpen, events, buttonsOverContent, className, parent, modalKey, }: ModalProps): JSX.Element | null;
declare namespace Modal {
    var displayName: string;
}

declare const optionIcon: {
    dry: SVGType;
    cold: SVGType;
    frozen: SVGType;
    errand: SVGType;
    halfDay: SVGType;
    day: SVGType;
    delivery: SVGType;
    carry: SVGType;
    moto: SVGType;
};

interface IOptionCard {
    text: string;
    icon: keyof typeof optionIcon | SVGType;
    description?: string;
    onClick?: () => void;
}
/**
 * `icon` prop can receive one of the accepted strings or an SVG. Remove the width and height from the svg to let the component assign it the ideal width.
 */
declare function OptionCard({ text, icon, description, onClick }: IOptionCard): JSX.Element;
declare namespace OptionCard {
    var displayName: string;
}

declare const methodIcon: {
    CreditCard: SVGType;
    Cash: SVGType;
    Bag: SVGType;
    PSE: SVGType;
    MercadoPago: SVGType;
};

interface PaymentMethodProps {
    title: string;
    description: string;
    onClick?: () => void;
    icon: keyof typeof methodIcon;
}
declare function PaymentMethod({ title, description, icon, onClick, }: PaymentMethodProps): JSX.Element;
declare namespace PaymentMethod {
    var displayName: string;
}

interface PopMenuProps {
    OpenIcon?: SVGType;
    CloseIcon?: SVGType;
    children: React$1.ReactNode;
    copies?: {
        close?: string;
    };
    zIndex?: number;
}
/**
 * The pop-up scales according to the width of the children elements.
 * To avoid elements being centered, wrap the children elements inside a div.
 */
declare function PopMenu({ OpenIcon, CloseIcon, children, copies, zIndex, }: PopMenuProps): JSX.Element;
declare namespace PopMenu {
    var displayName: string;
}

interface IinfoSelect {
    value: string;
    label: string;
}
interface IInput {
    placeHolder: string;
    type: 'number' | 'text';
}
interface ISelect {
    textDefault: string;
    data: IinfoSelect[];
}
interface IButton {
    text: string;
    onPressed: () => void;
}
interface IIconButton {
    Icon: SVGType;
    onPressed: () => void;
}
interface IEditMode {
    input: IInput;
    select_one: ISelect;
    select_two: ISelect;
    select_three: ISelect;
    buttonApprove: {
        text: string;
        onPressed: (inputValue: string, selectOneValue: string, selectTwoValue: string, selectThreeValue: string) => void;
    };
    buttonCancel: IButton;
}
interface ISaveMode {
    data: {
        value: string;
        Icon: SVGType;
    }[];
    buttonSurcharges: {
        number: number;
        text: string;
        Icon: SVGType;
    };
    buttonEdit: IIconButton;
    buttonDelete: IIconButton;
}
declare type IRates = ({
    mode: 'save';
} & ISaveMode) | ({
    mode: 'edit';
} & IEditMode);

declare const Rate: {
    ({ mode, ...IRates }: IRates): JSX.Element;
    displayName: string;
};

declare const variants: {
    0: string;
    1: string;
    2: string;
    3: string;
};
interface SelectProps extends DetailedHTMLProps<React$1.SelectHTMLAttributes<HTMLSelectElement>, HTMLSelectElement> {
    required?: boolean;
    handleChange?: React$1.ChangeEventHandler<HTMLSelectElement>;
    copies?: {
        title?: string;
        defaultLabel?: string;
    };
    options: Array<{
        value: string;
        label: string;
    }>;
    variant?: keyof typeof variants;
    disabled?: boolean;
    className?: string;
    value?: string;
}
declare const Select: React$1.ForwardRefExoticComponent<Pick<SelectProps, "variant" | "onChange" | "className" | "children" | "form" | "slot" | "style" | "title" | "color" | "translate" | "onClick" | "id" | "lang" | "name" | "role" | "tabIndex" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "key" | "copies" | "hidden" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "autoFocus" | "disabled" | "value" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "placeholder" | "spellCheck" | "radioGroup" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "autoComplete" | "multiple" | "required" | "size" | "options" | "handleChange"> & React$1.RefAttributes<HTMLSelectElement>>;

declare const StatusIcons: {
    initial: SVGType;
    onHold: SVGType;
    assigned: SVGType;
    cancelled: SVGType;
    finish: SVGType;
    transit: SVGType;
};

interface ServiceCardProps {
    icon: keyof typeof StatusIcons | SVGType;
    title: string;
    date: Date | number | string;
    elapsed?: string;
    className?: string;
    copies: {
        updated: string;
        timeDiff: string;
    };
}

declare const defaultCopies: {
    title: string;
    updated: string;
    timeDiff: string;
};
interface ServicesStateProps {
    states: Omit<ServiceCardProps, 'copies' | 'className'>[];
    copies?: Partial<typeof defaultCopies>;
    className?: string;
    contentClassName?: string;
}
declare function ServicesState({ copies, states, className, contentClassName, }: ServicesStateProps): JSX.Element;
declare namespace ServicesState {
    var displayName: string;
}

interface ISlideImageSelector {
    onChange: (selected: string | number) => void;
    data: Array<{
        image: string;
        caption: string;
        value: string | number;
    }>;
    className?: string;
}
declare function SlideImageSelector({ data, onChange, className, }: ISlideImageSelector): JSX.Element;
declare namespace SlideImageSelector {
    var displayName: string;
}

declare function Splash({ className }: {
    className?: string | undefined;
}): JSX.Element;
declare namespace Splash {
    var displayName: string;
}

declare const StateBadgeVariants: {
    grayBlue: string;
    red: string;
    yellow: string;
    green: string;
    gray: string;
    indigo: string;
};
interface StateBadgeProps {
    value: string;
    variant?: keyof typeof StateBadgeVariants | undefined;
}

declare function StateBadge({ value, variant }: StateBadgeProps): JSX.Element;
declare namespace StateBadge {
    var displayName: string;
}

interface IStepOption {
    text: string;
    icon: SVGType;
    onClick: () => void;
}
interface IStepper {
    data: IStepOption[];
    currentStep: number;
    className?: string;
}

declare function StepProgressBar({ data, currentStep, className }: IStepper): JSX.Element;
declare namespace StepProgressBar {
    var displayName: string;
}

interface DropdownEvidenceProps {
    title: string;
    index: string;
}

interface IStopCardProps {
    address: string;
    city: string;
    evidences: DropdownEvidenceProps[];
    novelty: string;
}

declare function StopCard({ address, city, evidences, novelty, }: IStopCardProps): JSX.Element;
declare namespace StopCard {
    var displayName: string;
}

interface SwitchProps extends Omit<DetailedHTMLProps<InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, 'type'> {
    text?: string;
    children?: ReactNode;
    handleChange?: React$1.ChangeEventHandler<HTMLInputElement>;
}
/**
 * `children` prop has priority over `text` in order to keep compatibility with previous component usages.
 * Use `flex-row-reverse` and `justify-between` as you see fit.
 */
declare const Switch: React$1.ForwardRefExoticComponent<Pick<SwitchProps, "onChange" | "className" | "children" | "form" | "slot" | "style" | "title" | "pattern" | "text" | "color" | "height" | "translate" | "width" | "onClick" | "list" | "id" | "lang" | "max" | "min" | "name" | "role" | "tabIndex" | "crossOrigin" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "key" | "hidden" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "autoFocus" | "disabled" | "formAction" | "formEncType" | "formMethod" | "formNoValidate" | "formTarget" | "value" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "placeholder" | "spellCheck" | "radioGroup" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "alt" | "src" | "checked" | "accept" | "autoComplete" | "capture" | "enterKeyHint" | "maxLength" | "minLength" | "multiple" | "readOnly" | "required" | "size" | "step" | "handleChange"> & React$1.RefAttributes<HTMLInputElement>>;

interface TableType<T extends object = {}> {
    (props: TableProps<T>): JSX.Element;
    ColumnsFilter: () => JSX.Element;
    Country: (props: {
        value: string;
    }) => JSX.Element;
    Currency: (props: {
        value: number;
        locale?: string;
        currency?: string;
        decimals?: number;
    }) => JSX.Element;
    DataTable: (props: {
        className?: string;
    }) => JSX.Element;
    Date: (props: {
        value: string;
    }) => JSX.Element;
    DefaultColumnFilter: <T extends object>(props: FilterProps<T>) => JSX.Element;
    ExportButton: () => JSX.Element;
    GlobalFilter: () => JSX.Element;
    TimeToService: (props: {
        original: any;
        value: any;
    }) => JSX.Element;
}
interface ITableCopies {
    notRegister: string;
    download: string;
    search: string;
    searchLarge: string;
}
interface TableProps<T extends object> {
    children: React$1.ReactNode;
    tableData: Array<T>;
    tableColumns: Array<Column<T> & ColumnInterface<T>>;
    rowClickHandler?: (row: Row<T>) => React$1.MouseEventHandler;
    columnFilters?: boolean;
    copies?: ITableCopies;
    className?: string;
}

declare function Table<T extends object>({ children, tableData, tableColumns, rowClickHandler, columnFilters, copies, className, }: TableProps<T>): JSX.Element;
declare namespace Table {
    var ColumnsFilter: ({ zIndex }: {
        zIndex?: number | undefined;
    }) => JSX.Element;
    var Country: ({ value }: {
        value: string;
    }) => JSX.Element;
    var Currency: ({ value, locale, currency, decimals, }: {
        value: number;
        locale?: string | undefined;
        currency?: string | undefined;
        decimals?: number | undefined;
    }) => JSX.Element;
    var DataTable: ({ className }: {
        className?: string | undefined;
    }) => JSX.Element;
    var Date: ({ value }: {
        value: string;
    }) => JSX.Element;
    var DefaultColumnFilter: <T extends object = any>({ column: { filterValue, preFilteredRows, setFilter }, }: react_table.FilterProps<T>) => JSX.Element;
    var ExportButton: () => JSX.Element;
    var GlobalFilter: () => JSX.Element;
    var TimeToService: ({ value }: {
        value: string;
    }) => JSX.Element;
    var displayName: string;
}

interface TabChildProps {
    children: ReactNode | (() => ReactNode);
    eventKey: string;
    title: string;
}
interface TabListProps {
    children: ReactNode | ReactNode[];
    className?: string;
}
interface TabsProps {
    children: ReactElement<TabListProps>;
    activeKey: string;
    variant: 'H' | 'V';
    className?: string;
    containerClassName?: string;
    breakpoint?: `${number}${'px' | 'em' | 'ex' | 'rem' | 'ch'}`;
    onChange?: (tab: string) => void;
    fallback?: string;
}

/** Must be inside Tabs component. */
declare const TabList: React$1.FC<TabListProps>;

/** Must be inside a TabList component.
 * Wrap your children with `{() => ...}` if you want a lazy tab.
 */
declare const Tab: ({ eventKey, title, children: Children }: TabChildProps) => JSX.Element;

/** It's child must be `TabList` component, whose childs must be `Tab` components. `activeKey` must be one of the `eventKey`s passed to child tab components. */
declare function Tabs({ children, activeKey, variant, className, containerClassName, breakpoint, fallback, onChange, }: TabsProps): JSX.Element;
declare namespace Tabs {
    var displayName: string;
}

interface TagProps {
    text: string;
}
declare function Tag({ text }: TagProps): JSX.Element;
declare namespace Tag {
    var displayName: string;
}

interface ITextAreaProps {
    title?: string;
    placeholder: string;
    handleChange: (value: string, valid: boolean) => void;
    validator?: {
        test: (value: string) => boolean;
    };
    value?: string;
}
declare const TextArea: React$1.ForwardRefExoticComponent<ITextAreaProps & React$1.RefAttributes<HTMLTextAreaElement>>;

export { Alert, AlertProps, AlertVariants, BackButton, BackButtonProps, BagTransactionSummary, Breadcrumb, BreadcrumbProps, Button, ButtonAdd, ButtonProps, Card, CardProps, CardStatistics, CardStatisticsProps, Comment, CommentProps, Counter, CounterProps, CreditCard, DarkModeSwitcher, Details, FlatPicker, FlatPickerProps, GridInfo, GridInfoProps, IBagTransactionSummary, ICreditCard, IDarkModeSwitcher, IDetails, IIconSelect, IMenuProps, IOptionCard, ISlideImageSelector, IStepper, IStopCardProps, ITextAreaProps, ITimePicker, IconInfo, IconInfoProps, IconInfoVariants, IconSelect, Input, InputProps, Line, LineCard, LineCardProps, LineProps, LinkServices, LinkServicesProps, LoadFile, LoadFileProps, Login, LoginProps, LookImage, LookImageProps, Map, MapProps, Menu, Modal, ModalProps, OptionCard, PaymentMethod, PaymentMethodProps, PopMenu, PopMenuProps, Rate, Select, SelectProps, ServicesState, ServicesStateProps, SlideImageSelector, Splash, StateBadge, StateBadgeProps, StepProgressBar, StopCard, Switch, SwitchProps, Tab, TabList, Table, TableProps, TableType, Tabs, TabsProps, Tag, TagProps, TextArea, TimePicker };
